;; Generated package description from forgejo.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "forgejo" "0.1.3" "Emacs Forgejo Front-end" '((emacs "29.1") (keymap-popup "0.2.1")) :commit "008ee859c0c7bb2b18995d39310ddb8121a1c3c2" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("tools" "vc" "git" "forgejo") :url "https://codeberg.org/thanosapollo/emacs-forgejo")
